@@ -69,7 +69,7 @@ def ec_filename_for(path):
     return fn
 
 
-def tweak(easyconfigs, build_specs):
+def tweak(easyconfigs, build_specs, targetdir=None):
     """Tweak list of easyconfigs according to provided build specifications."""
 
     # make sure easyconfigs all feature the same toolchain (otherwise we *will* run into trouble)
@@ -77,6 +77,21 @@ def tweak(easyconfigs, build_specs):
     if len(toolchains) > 1:
         _log.error("Multiple toolchains featured in easyconfigs, --try-X not supported in that case: %s" % toolchains)
 
+    if 'name' in build_specs or 'version' in build_specs:
+        # no recursion if software name/version build specification are included
+        # in that case, do not construct full dependency graph
+        orig_ecs = easyconfigs
+        _log.debug("Software name/version found, so not applying build specifications recursively: %s" % build_specs)
+    else:
+        # build specifications should be applied to the whole dependency graph
+        # obtain full dependency graph for specified easyconfigs
+        # easyconfigs will be ordered 'top-to-bottom': toolchain dependencies and toolchain first
+        _log.debug("Applying build specifications recursively (no software name/version found): %s" % build_specs)
+        orig_ecs = resolve_dependencies(easyconfigs, retain_all_deps=True)
+
+    # keep track of originally listed easyconfigs (via their path)
+    listed_ec_paths = [ec['spec'] for ec in easyconfigs]
+
     # obtain full dependency graph for specified easyconfigs
     # easyconfigs will be ordered 'top-to-bottom': toolchain dependencies and toolchain first
     orig_ecs = resolve_dependencies(easyconfigs, retain_all_deps=True)
@@ -91,16 +106,19 @@ def tweak(easyconfigs, build_specs):
             orig_ecs = orig_ecs[1:]
 
     # generate tweaked easyconfigs, and continue with those instead
-    easyconfigs = []
+    tweaked_easyconfigs = []
     for orig_ec in orig_ecs:
-        new_ec_file = tweak_one(orig_ec['spec'], None, build_specs)
-        new_ecs = process_easyconfig(new_ec_file, build_specs=build_specs)
-        easyconfigs.extend(new_ecs)
+        new_ec_file = tweak_one(orig_ec['spec'], None, build_specs, targetdir=targetdir)
+        # only return tweaked easyconfigs for easyconfigs which were listed originally
+        # easyconfig files for dependencies are also generated but not included, and will be resolved via --robot
+        if orig_ec['spec'] in listed_ec_paths:
+            new_ecs = process_easyconfig(new_ec_file, build_specs=build_specs)
+            tweaked_easyconfigs.extend(new_ecs)
 
-    return easyconfigs
+    return tweaked_easyconfigs
 
 
-def tweak_one(src_fn, target_fn, tweaks):
+def tweak_one(src_fn, target_fn, tweaks, targetdir=None):
     """
     Tweak an easyconfig file with the given list of tweaks, using replacement via regular expressions.
     Note: this will only work 'well-written' easyconfig files, i.e. ones that e.g. set the version
@@ -222,7 +240,9 @@ def tweak_one(src_fn, target_fn, tweaks):
         except OSError, err:
             _log.error("Failed to determine suiting filename for tweaked easyconfig file: %s" % err)
 
-        target_fn = os.path.join(tempfile.gettempdir(), fn)
+        if targetdir is None:
+            targetdir = tempfile.gettempdir()
+        target_fn = os.path.join(targetdir, fn)
         _log.debug("Generated file name for tweaked easyconfig file: %s" % target_fn)
 
     # write out tweaked easyconfig file
